# pyMaBoSS

[![Documentation Status](https://readthedocs.org/projects/pymaboss/badge/?version=latest)](http://pymaboss.readthedocs.io/en/latest/?badge=latest)
[![PyPI version](https://badge.fury.io/py/maboss.svg)](https://badge.fury.io/py/maboss)

Python interface for the MaBoSS software (https://maboss.curie.fr)
